/* HC-SR04 Sensor
   https://www.dealextreme.com/p/hc-sr04-ultrasonic-sensor-distance-measuring-module-133696
  
   This sketch reads a HC-SR04 ultrasonic rangefinder and returns the
   distance to the closest object in range. To do this, it sends a pulse
   to the sensor to initiate a reading, then listens for a pulse 
   to return.  The length of the returning pulse is proportional to 
   the distance of the object from the sensor.
     
   The circuit:
	* VCC connection of the sensor attached to +5V
	* GND connection of the sensor attached to ground
	* TRIG connection of the sensor attached to digital pin 5
	* ECHO connection of the sensor attached to digital pin 3


   Original code for Ping))) example was created by David A. Mellis
   Adapted for sonar-display by Maria Melo Bento

   This example code is in the public domain.
 */
// Use the softwareserial library to create a new "soft" serial port
// for the display. This prevents display corruption when uploading code.
#include <SoftwareSerial.h>

// Attach the serial display's RX line to digital pin 2
SoftwareSerial mySerial(0,1); // pin 2 = TX, pin 3 = RX (unused)

const int trigPin = 5;
const int echoPin = 3;

void setup() {
  // initialize serial communication:
  mySerial.begin(9600);
  delay(500); // wait for display to boot up
  mySerial.write(254); // cursor to beginning of first line
  mySerial.write(128);
  mySerial.write("Maria'S-kinetic!"); // clear display + legends
  
  mySerial.write("Dist:       cm");
}

char cmstring[10]; // create string arrays

void loop()
{
  // establish variables for duration of the ping, 
  // and the distance result centimeters:
  long duration, cm;

  // The sensor is triggered by a HIGH pulse of 10 or more microseconds.
  // Give a short LOW pulse beforehand to ensure a clean HIGH pulse:
  pinMode(trigPin, OUTPUT);
  digitalWrite(trigPin, LOW);
  delayMicroseconds(2);
  digitalWrite(trigPin, HIGH);
  delayMicroseconds(10);
  digitalWrite(trigPin, LOW);

  // Read the signal from the sensor: a HIGH pulse whose
  // duration is the time (in microseconds) from the sending
  // of the ping to the reception of its echo off of an object.
  pinMode(echoPin, INPUT);
  duration = pulseIn(echoPin, HIGH);

  // convert the time into a distance
 
  cm = microsecondsToCentimeters(duration);
  
  sprintf(cmstring,"%4d",cm); // create strings from the numbers
  
  mySerial.write(254); // cursor to 7th position on second line
  mySerial.write(198);

  mySerial.write(cmstring); // write out the TEMP value
  
//  Serial.print(cm);

// Serial.print("cm");
  Serial.println();
  
  delay(50);
}


long microsecondsToCentimeters(long microseconds)
{
  // The speed of sound is 340 m/s or 29 microseconds per centimeter.
  // The ping travels out and back, so to find the distance of the
  // object we take half of the distance travelled.
  return microseconds / 29 / 2;
}
